pub struct InputState { /* private fields */ }Implementations
Sourceimpl InputState
impl InputState
pub fn new() -> Self
Sourcepub fn begin_frame(&mut self)
pub fn begin_frame(&mut self)
Call at the start of each frame to clear “just pressed/released” states
Sourcepub fn on_key_pressed(&mut self, key_code: KeyCode)
pub fn on_key_pressed(&mut self, key_code: KeyCode)
Handle key pressed event
Sourcepub fn on_key_released(&mut self, key_code: KeyCode)
pub fn on_key_released(&mut self, key_code: KeyCode)
Handle key released event
Handle mouse button pressed
Handle mouse button released
Sourcepub fn on_cursor_moved(&mut self, x: f32, y: f32)
pub fn on_cursor_moved(&mut self, x: f32, y: f32)
Handle mouse cursor moved
Sourcepub fn on_mouse_wheel(&mut self, delta_x: f32, delta_y: f32)
pub fn on_mouse_wheel(&mut self, delta_x: f32, delta_y: f32)
Handle mouse wheel/scroll
Sourcepub fn is_key_pressed(&self, key_code: KeyCode) -> bool
pub fn is_key_pressed(&self, key_code: KeyCode) -> bool
Check if a key is currently pressed
Sourcepub fn is_key_just_pressed(&self, key_code: KeyCode) -> bool
pub fn is_key_just_pressed(&self, key_code: KeyCode) -> bool
Check if a key was just pressed this frame
Sourcepub fn is_key_just_released(&self, key_code: KeyCode) -> bool
pub fn is_key_just_released(&self, key_code: KeyCode) -> bool
Check if a key was just released this frame
Sourcepub fn mouse_position(&self) -> (f32, f32)
pub fn mouse_position(&self) -> (f32, f32)
Get mouse position
Sourcepub fn mouse_delta(&self) -> (f32, f32)
pub fn mouse_delta(&self) -> (f32, f32)
Get mouse delta (change in position this frame)
Check if a mouse button is currently pressed
Check if a mouse button was just pressed this frame
Sourcepub fn mouse_scroll(&self) -> (f32, f32)
pub fn mouse_scroll(&self) -> (f32, f32)
Get mouse scroll delta for this frame