pub struct GetAddressHexResponse {
pub hex: String,
}Fields
hex: StringTrait Implementations
Sourceimpl Clone for GetAddressHexResponse
impl Clone for GetAddressHexResponse
Sourcefn clone(&self) -> GetAddressHexResponse
fn clone(&self) -> GetAddressHexResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetAddressHexResponse
impl Debug for GetAddressHexResponse
Sourceimpl<'de> Deserialize<'de> for GetAddressHexResponse
impl<'de> Deserialize<'de> for GetAddressHexResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GetAddressHexResponse
impl JsonSchema for GetAddressHexResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GetAddressHexResponse
impl PartialEq for GetAddressHexResponse
Sourcefn eq(&self, other: &GetAddressHexResponse) -> bool
fn eq(&self, other: &GetAddressHexResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for GetAddressHexResponse
impl Serialize for GetAddressHexResponse
impl StructuralPartialEq for GetAddressHexResponse