pub struct GuardianSetInfoResponse {
pub guardian_set_index: u32,
pub addresses: Vec<GuardianAddress>,
}Fields
guardian_set_index: u32addresses: Vec<GuardianAddress>Trait Implementations
Sourceimpl Clone for GuardianSetInfoResponse
impl Clone for GuardianSetInfoResponse
Sourcefn clone(&self) -> GuardianSetInfoResponse
fn clone(&self) -> GuardianSetInfoResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GuardianSetInfoResponse
impl Debug for GuardianSetInfoResponse
Sourceimpl<'de> Deserialize<'de> for GuardianSetInfoResponse
impl<'de> Deserialize<'de> for GuardianSetInfoResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GuardianSetInfoResponse
impl JsonSchema for GuardianSetInfoResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GuardianSetInfoResponse
impl PartialEq for GuardianSetInfoResponse
Sourcefn eq(&self, other: &GuardianSetInfoResponse) -> bool
fn eq(&self, other: &GuardianSetInfoResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for GuardianSetInfoResponse
impl Serialize for GuardianSetInfoResponse
impl StructuralPartialEq for GuardianSetInfoResponse