pub struct WrappedRegistryResponse {
pub address: String,
}Fields
address: StringTrait Implementations
Sourceimpl Clone for WrappedRegistryResponse
impl Clone for WrappedRegistryResponse
Sourcefn clone(&self) -> WrappedRegistryResponse
fn clone(&self) -> WrappedRegistryResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WrappedRegistryResponse
impl Debug for WrappedRegistryResponse
Sourceimpl<'de> Deserialize<'de> for WrappedRegistryResponse
impl<'de> Deserialize<'de> for WrappedRegistryResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WrappedRegistryResponse
impl JsonSchema for WrappedRegistryResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for WrappedRegistryResponse
impl PartialEq for WrappedRegistryResponse
Sourcefn eq(&self, other: &WrappedRegistryResponse) -> bool
fn eq(&self, other: &WrappedRegistryResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for WrappedRegistryResponse
impl Serialize for WrappedRegistryResponse
impl StructuralPartialEq for WrappedRegistryResponse