pub enum ContractError {
Show 24 variants
InvalidVersion,
InvalidGuardianSetIndex,
GuardianSetExpired,
NoQuorum,
WrongGuardianIndexOrder,
CannotDecodeSignature,
CannotRecoverKey,
GuardianSignatureError,
InvalidVAAAction,
NotCurrentGuardianSet,
AmountTooHigh,
AmountTooLow,
SameSourceAndTarget,
WrongTargetChain,
AssetAlreadyRegistered,
GuardianSetIndexIncreaseError,
VaaAlreadyExecuted,
PermissionDenied,
WrongTargetAddressFormat,
TooManySignatures,
AssetNotFound,
InvalidVAA,
FeeTooLow,
RegistrationForbidden,
}Variants
InvalidVersion
Invalid VAA version
InvalidGuardianSetIndex
Guardian set with this index does not exist
GuardianSetExpired
Guardian set expiration date is zero or in the past
NoQuorum
Not enough signers on the VAA
WrongGuardianIndexOrder
Wrong guardian index order, order must be ascending
CannotDecodeSignature
Some problem with signature decoding from bytes
CannotRecoverKey
Some problem with public key recovery from the signature
GuardianSignatureError
Recovered pubkey from signature does not match guardian address
InvalidVAAAction
VAA action code not recognized
NotCurrentGuardianSet
VAA guardian set is not current
AmountTooHigh
Only 128-bit amounts are supported
AmountTooLow
Amount should be higher than zero
SameSourceAndTarget
Source and target chain ids must be different
WrongTargetChain
Target chain id must be the same as the current CHAIN_ID
AssetAlreadyRegistered
Wrapped asset init hook sent twice for the same asset id
GuardianSetIndexIncreaseError
Guardian set must increase in steps of 1
VaaAlreadyExecuted
VAA was already executed
PermissionDenied
Message sender not permitted to execute this operation
WrongTargetAddressFormat
Could not decode target address from canonical to human-readable form
TooManySignatures
More signatures than active guardians found
AssetNotFound
Wrapped asset not found in the registry
InvalidVAA
Generic error when there is a problem with VAA structure
FeeTooLow
Thrown when fee is enabled for the action, but was not sent with the transaction
RegistrationForbidden
Registering asset outside of the wormhole