InputState

Struct InputState 

pub struct InputState { /* private fields */ }

Implementations

Source

impl InputState

pub fn new() -> Self

pub fn begin_frame(&mut self)

Call at the start of each frame to clear “just pressed/released” states

pub fn end_frame(&mut self)

Call at the end of each frame

pub fn on_key_pressed(&mut self, key_code: KeyCode)

Handle key pressed event

pub fn on_key_released(&mut self, key_code: KeyCode)

Handle key released event

pub fn on_mouse_button_pressed(&mut self, button: MouseButton)

Handle mouse button pressed

pub fn on_mouse_button_released(&mut self, button: MouseButton)

Handle mouse button released

pub fn on_cursor_moved(&mut self, x: f32, y: f32)

Handle mouse cursor moved

pub fn on_mouse_wheel(&mut self, delta_x: f32, delta_y: f32)

Handle mouse wheel/scroll

pub fn is_key_pressed(&self, key_code: KeyCode) -> bool

Check if a key is currently pressed

pub fn is_key_just_pressed(&self, key_code: KeyCode) -> bool

Check if a key was just pressed this frame

pub fn is_key_just_released(&self, key_code: KeyCode) -> bool

Check if a key was just released this frame

pub fn mouse_position(&self) -> (f32, f32)

Get mouse position

pub fn mouse_delta(&self) -> (f32, f32)

Get mouse delta (change in position this frame)

pub fn is_mouse_button_pressed(&self, button: MouseButton) -> bool

Check if a mouse button is currently pressed

pub fn is_mouse_button_just_pressed(&self, button: MouseButton) -> bool

Check if a mouse button was just pressed this frame

pub fn mouse_scroll(&self) -> (f32, f32)

Get mouse scroll delta for this frame